@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,9 +24,7 @@ CreateColorGui_test::CreateColorGui_test(QWidget *parent)
     createListWidgetItem();
 }
 
-CreateColorGui_test::~CreateColorGui_test()
-{
-}
+CreateColorGui_test::~CreateColorGui_test() = default;
 
 void CreateColorGui_test::createListWidgetItem()
 {
